@@ -5,8 +5,9 @@
 
 #define N 16
 
-/* unaligned load.  */
+/* indirect access.  */
 
+__attribute__ ((noinline))
 int main1 ()
 {
   int i;
